Documentation
¶
Overview ¶
Package managementproto contains the protobufer and gRPC generated sources for the management interface
Index ¶
- func RegisterHordeManagementServiceServer(s *grpc.Server, srv HordeManagementServiceServer)
- type APN
- func (*APN) Descriptor() ([]byte, []int)
- func (m *APN) GetApnID() int32
- func (m *APN) GetName() string
- func (*APN) ProtoMessage()
- func (m *APN) Reset()
- func (m *APN) String() string
- func (m *APN) XXX_DiscardUnknown()
- func (m *APN) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *APN) XXX_Merge(src proto.Message)
- func (m *APN) XXX_Size() int
- func (m *APN) XXX_Unmarshal(b []byte) error
- type APNAllocation
- func (*APNAllocation) Descriptor() ([]byte, []int)
- func (m *APNAllocation) GetCreated() int64
- func (m *APNAllocation) GetIMEI() int64
- func (m *APNAllocation) GetIMSI() int64
- func (m *APNAllocation) GetIP() string
- func (m *APNAllocation) GetNasID() int32
- func (*APNAllocation) ProtoMessage()
- func (m *APNAllocation) Reset()
- func (m *APNAllocation) String() string
- func (m *APNAllocation) XXX_DiscardUnknown()
- func (m *APNAllocation) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *APNAllocation) XXX_Merge(src proto.Message)
- func (m *APNAllocation) XXX_Size() int
- func (m *APNAllocation) XXX_Unmarshal(b []byte) error
- type APNConfig
- func (*APNConfig) Descriptor() ([]byte, []int)
- func (m *APNConfig) GetAPN() *APN
- func (m *APNConfig) GetNasRanges() []*NASRange
- func (*APNConfig) ProtoMessage()
- func (m *APNConfig) Reset()
- func (m *APNConfig) String() string
- func (m *APNConfig) XXX_DiscardUnknown()
- func (m *APNConfig) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *APNConfig) XXX_Merge(src proto.Message)
- func (m *APNConfig) XXX_Size() int
- func (m *APNConfig) XXX_Unmarshal(b []byte) error
- type AddAPNRequest
- func (*AddAPNRequest) Descriptor() ([]byte, []int)
- func (m *AddAPNRequest) GetNewAPN() *APN
- func (*AddAPNRequest) ProtoMessage()
- func (m *AddAPNRequest) Reset()
- func (m *AddAPNRequest) String() string
- func (m *AddAPNRequest) XXX_DiscardUnknown()
- func (m *AddAPNRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *AddAPNRequest) XXX_Merge(src proto.Message)
- func (m *AddAPNRequest) XXX_Size() int
- func (m *AddAPNRequest) XXX_Unmarshal(b []byte) error
- type AddAPNResponse
- func (*AddAPNResponse) Descriptor() ([]byte, []int)
- func (m *AddAPNResponse) GetResult() *Result
- func (*AddAPNResponse) ProtoMessage()
- func (m *AddAPNResponse) Reset()
- func (m *AddAPNResponse) String() string
- func (m *AddAPNResponse) XXX_DiscardUnknown()
- func (m *AddAPNResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *AddAPNResponse) XXX_Merge(src proto.Message)
- func (m *AddAPNResponse) XXX_Size() int
- func (m *AddAPNResponse) XXX_Unmarshal(b []byte) error
- type AddAllocationRequest
- func (*AddAllocationRequest) Descriptor() ([]byte, []int)
- func (m *AddAllocationRequest) GetApnID() int32
- func (m *AddAllocationRequest) GetIMSI() int64
- func (m *AddAllocationRequest) GetIP() string
- func (m *AddAllocationRequest) GetNasID() int32
- func (*AddAllocationRequest) ProtoMessage()
- func (m *AddAllocationRequest) Reset()
- func (m *AddAllocationRequest) String() string
- func (m *AddAllocationRequest) XXX_DiscardUnknown()
- func (m *AddAllocationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *AddAllocationRequest) XXX_Merge(src proto.Message)
- func (m *AddAllocationRequest) XXX_Size() int
- func (m *AddAllocationRequest) XXX_Unmarshal(b []byte) error
- type AddAllocationResponse
- func (*AddAllocationResponse) Descriptor() ([]byte, []int)
- func (m *AddAllocationResponse) GetResult() *Result
- func (*AddAllocationResponse) ProtoMessage()
- func (m *AddAllocationResponse) Reset()
- func (m *AddAllocationResponse) String() string
- func (m *AddAllocationResponse) XXX_DiscardUnknown()
- func (m *AddAllocationResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *AddAllocationResponse) XXX_Merge(src proto.Message)
- func (m *AddAllocationResponse) XXX_Size() int
- func (m *AddAllocationResponse) XXX_Unmarshal(b []byte) error
- type AddNASRequest
- func (*AddNASRequest) Descriptor() ([]byte, []int)
- func (m *AddNASRequest) GetApnID() int32
- func (m *AddNASRequest) GetNewRange() *NASRange
- func (*AddNASRequest) ProtoMessage()
- func (m *AddNASRequest) Reset()
- func (m *AddNASRequest) String() string
- func (m *AddNASRequest) XXX_DiscardUnknown()
- func (m *AddNASRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *AddNASRequest) XXX_Merge(src proto.Message)
- func (m *AddNASRequest) XXX_Size() int
- func (m *AddNASRequest) XXX_Unmarshal(b []byte) error
- type AddNASResponse
- func (*AddNASResponse) Descriptor() ([]byte, []int)
- func (m *AddNASResponse) GetResult() *Result
- func (*AddNASResponse) ProtoMessage()
- func (m *AddNASResponse) Reset()
- func (m *AddNASResponse) String() string
- func (m *AddNASResponse) XXX_DiscardUnknown()
- func (m *AddNASResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *AddNASResponse) XXX_Merge(src proto.Message)
- func (m *AddNASResponse) XXX_Size() int
- func (m *AddNASResponse) XXX_Unmarshal(b []byte) error
- type AddTokenRequest
- func (*AddTokenRequest) Descriptor() ([]byte, []int)
- func (m *AddTokenRequest) GetUserId() string
- func (*AddTokenRequest) ProtoMessage()
- func (m *AddTokenRequest) Reset()
- func (m *AddTokenRequest) String() string
- func (m *AddTokenRequest) XXX_DiscardUnknown()
- func (m *AddTokenRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *AddTokenRequest) XXX_Merge(src proto.Message)
- func (m *AddTokenRequest) XXX_Size() int
- func (m *AddTokenRequest) XXX_Unmarshal(b []byte) error
- type AddTokenResponse
- func (*AddTokenResponse) Descriptor() ([]byte, []int)
- func (m *AddTokenResponse) GetApiToken() string
- func (m *AddTokenResponse) GetResult() *Result
- func (*AddTokenResponse) ProtoMessage()
- func (m *AddTokenResponse) Reset()
- func (m *AddTokenResponse) String() string
- func (m *AddTokenResponse) XXX_DiscardUnknown()
- func (m *AddTokenResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *AddTokenResponse) XXX_Merge(src proto.Message)
- func (m *AddTokenResponse) XXX_Size() int
- func (m *AddTokenResponse) XXX_Unmarshal(b []byte) error
- type AddUserRequest
- func (*AddUserRequest) Descriptor() ([]byte, []int)
- func (m *AddUserRequest) GetEmail() string
- func (m *AddUserRequest) GetName() string
- func (*AddUserRequest) ProtoMessage()
- func (m *AddUserRequest) Reset()
- func (m *AddUserRequest) String() string
- func (m *AddUserRequest) XXX_DiscardUnknown()
- func (m *AddUserRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *AddUserRequest) XXX_Merge(src proto.Message)
- func (m *AddUserRequest) XXX_Size() int
- func (m *AddUserRequest) XXX_Unmarshal(b []byte) error
- type AddUserResponse
- func (*AddUserResponse) Descriptor() ([]byte, []int)
- func (m *AddUserResponse) GetApiToken() string
- func (m *AddUserResponse) GetResult() *Result
- func (m *AddUserResponse) GetUserId() string
- func (*AddUserResponse) ProtoMessage()
- func (m *AddUserResponse) Reset()
- func (m *AddUserResponse) String() string
- func (m *AddUserResponse) XXX_DiscardUnknown()
- func (m *AddUserResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *AddUserResponse) XXX_Merge(src proto.Message)
- func (m *AddUserResponse) XXX_Size() int
- func (m *AddUserResponse) XXX_Unmarshal(b []byte) error
- type HordeManagementServiceClient
- type HordeManagementServiceServer
- type ListAPNAllocationsRequest
- func (*ListAPNAllocationsRequest) Descriptor() ([]byte, []int)
- func (m *ListAPNAllocationsRequest) GetApnID() int32
- func (m *ListAPNAllocationsRequest) GetNasID() int32
- func (*ListAPNAllocationsRequest) ProtoMessage()
- func (m *ListAPNAllocationsRequest) Reset()
- func (m *ListAPNAllocationsRequest) String() string
- func (m *ListAPNAllocationsRequest) XXX_DiscardUnknown()
- func (m *ListAPNAllocationsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ListAPNAllocationsRequest) XXX_Merge(src proto.Message)
- func (m *ListAPNAllocationsRequest) XXX_Size() int
- func (m *ListAPNAllocationsRequest) XXX_Unmarshal(b []byte) error
- type ListAPNAllocationsResponse
- func (*ListAPNAllocationsResponse) Descriptor() ([]byte, []int)
- func (m *ListAPNAllocationsResponse) GetAllocations() []*APNAllocation
- func (m *ListAPNAllocationsResponse) GetResult() *Result
- func (*ListAPNAllocationsResponse) ProtoMessage()
- func (m *ListAPNAllocationsResponse) Reset()
- func (m *ListAPNAllocationsResponse) String() string
- func (m *ListAPNAllocationsResponse) XXX_DiscardUnknown()
- func (m *ListAPNAllocationsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ListAPNAllocationsResponse) XXX_Merge(src proto.Message)
- func (m *ListAPNAllocationsResponse) XXX_Size() int
- func (m *ListAPNAllocationsResponse) XXX_Unmarshal(b []byte) error
- type ListAPNRequest
- func (*ListAPNRequest) Descriptor() ([]byte, []int)
- func (*ListAPNRequest) ProtoMessage()
- func (m *ListAPNRequest) Reset()
- func (m *ListAPNRequest) String() string
- func (m *ListAPNRequest) XXX_DiscardUnknown()
- func (m *ListAPNRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ListAPNRequest) XXX_Merge(src proto.Message)
- func (m *ListAPNRequest) XXX_Size() int
- func (m *ListAPNRequest) XXX_Unmarshal(b []byte) error
- type ListAPNResponse
- func (*ListAPNResponse) Descriptor() ([]byte, []int)
- func (m *ListAPNResponse) GetAPNs() []*APNConfig
- func (m *ListAPNResponse) GetResult() *Result
- func (*ListAPNResponse) ProtoMessage()
- func (m *ListAPNResponse) Reset()
- func (m *ListAPNResponse) String() string
- func (m *ListAPNResponse) XXX_DiscardUnknown()
- func (m *ListAPNResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ListAPNResponse) XXX_Merge(src proto.Message)
- func (m *ListAPNResponse) XXX_Size() int
- func (m *ListAPNResponse) XXX_Unmarshal(b []byte) error
- type NASRange
- func (*NASRange) Descriptor() ([]byte, []int)
- func (m *NASRange) GetCIDR() string
- func (m *NASRange) GetNasID() int32
- func (m *NASRange) GetNasIdentifier() string
- func (*NASRange) ProtoMessage()
- func (m *NASRange) Reset()
- func (m *NASRange) String() string
- func (m *NASRange) XXX_DiscardUnknown()
- func (m *NASRange) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *NASRange) XXX_Merge(src proto.Message)
- func (m *NASRange) XXX_Size() int
- func (m *NASRange) XXX_Unmarshal(b []byte) error
- type ReloadAPNRequest
- func (*ReloadAPNRequest) Descriptor() ([]byte, []int)
- func (*ReloadAPNRequest) ProtoMessage()
- func (m *ReloadAPNRequest) Reset()
- func (m *ReloadAPNRequest) String() string
- func (m *ReloadAPNRequest) XXX_DiscardUnknown()
- func (m *ReloadAPNRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ReloadAPNRequest) XXX_Merge(src proto.Message)
- func (m *ReloadAPNRequest) XXX_Size() int
- func (m *ReloadAPNRequest) XXX_Unmarshal(b []byte) error
- type ReloadAPNResponse
- func (*ReloadAPNResponse) Descriptor() ([]byte, []int)
- func (m *ReloadAPNResponse) GetResult() *Result
- func (*ReloadAPNResponse) ProtoMessage()
- func (m *ReloadAPNResponse) Reset()
- func (m *ReloadAPNResponse) String() string
- func (m *ReloadAPNResponse) XXX_DiscardUnknown()
- func (m *ReloadAPNResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ReloadAPNResponse) XXX_Merge(src proto.Message)
- func (m *ReloadAPNResponse) XXX_Size() int
- func (m *ReloadAPNResponse) XXX_Unmarshal(b []byte) error
- type RemoveAPNAllocationRequest
- func (*RemoveAPNAllocationRequest) Descriptor() ([]byte, []int)
- func (m *RemoveAPNAllocationRequest) GetApnID() int32
- func (m *RemoveAPNAllocationRequest) GetIMSI() int64
- func (m *RemoveAPNAllocationRequest) GetNasID() int32
- func (*RemoveAPNAllocationRequest) ProtoMessage()
- func (m *RemoveAPNAllocationRequest) Reset()
- func (m *RemoveAPNAllocationRequest) String() string
- func (m *RemoveAPNAllocationRequest) XXX_DiscardUnknown()
- func (m *RemoveAPNAllocationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *RemoveAPNAllocationRequest) XXX_Merge(src proto.Message)
- func (m *RemoveAPNAllocationRequest) XXX_Size() int
- func (m *RemoveAPNAllocationRequest) XXX_Unmarshal(b []byte) error
- type RemoveAPNAllocationResponse
- func (*RemoveAPNAllocationResponse) Descriptor() ([]byte, []int)
- func (m *RemoveAPNAllocationResponse) GetResult() *Result
- func (*RemoveAPNAllocationResponse) ProtoMessage()
- func (m *RemoveAPNAllocationResponse) Reset()
- func (m *RemoveAPNAllocationResponse) String() string
- func (m *RemoveAPNAllocationResponse) XXX_DiscardUnknown()
- func (m *RemoveAPNAllocationResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *RemoveAPNAllocationResponse) XXX_Merge(src proto.Message)
- func (m *RemoveAPNAllocationResponse) XXX_Size() int
- func (m *RemoveAPNAllocationResponse) XXX_Unmarshal(b []byte) error
- type RemoveAPNRequest
- func (*RemoveAPNRequest) Descriptor() ([]byte, []int)
- func (m *RemoveAPNRequest) GetApnID() int32
- func (*RemoveAPNRequest) ProtoMessage()
- func (m *RemoveAPNRequest) Reset()
- func (m *RemoveAPNRequest) String() string
- func (m *RemoveAPNRequest) XXX_DiscardUnknown()
- func (m *RemoveAPNRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *RemoveAPNRequest) XXX_Merge(src proto.Message)
- func (m *RemoveAPNRequest) XXX_Size() int
- func (m *RemoveAPNRequest) XXX_Unmarshal(b []byte) error
- type RemoveAPNResponse
- func (*RemoveAPNResponse) Descriptor() ([]byte, []int)
- func (m *RemoveAPNResponse) GetResult() *Result
- func (*RemoveAPNResponse) ProtoMessage()
- func (m *RemoveAPNResponse) Reset()
- func (m *RemoveAPNResponse) String() string
- func (m *RemoveAPNResponse) XXX_DiscardUnknown()
- func (m *RemoveAPNResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *RemoveAPNResponse) XXX_Merge(src proto.Message)
- func (m *RemoveAPNResponse) XXX_Size() int
- func (m *RemoveAPNResponse) XXX_Unmarshal(b []byte) error
- type RemoveNASRequest
- func (*RemoveNASRequest) Descriptor() ([]byte, []int)
- func (m *RemoveNASRequest) GetApnID() int32
- func (m *RemoveNASRequest) GetNasID() int32
- func (*RemoveNASRequest) ProtoMessage()
- func (m *RemoveNASRequest) Reset()
- func (m *RemoveNASRequest) String() string
- func (m *RemoveNASRequest) XXX_DiscardUnknown()
- func (m *RemoveNASRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *RemoveNASRequest) XXX_Merge(src proto.Message)
- func (m *RemoveNASRequest) XXX_Size() int
- func (m *RemoveNASRequest) XXX_Unmarshal(b []byte) error
- type RemoveNASResponse
- func (*RemoveNASResponse) Descriptor() ([]byte, []int)
- func (m *RemoveNASResponse) GetResult() *Result
- func (*RemoveNASResponse) ProtoMessage()
- func (m *RemoveNASResponse) Reset()
- func (m *RemoveNASResponse) String() string
- func (m *RemoveNASResponse) XXX_DiscardUnknown()
- func (m *RemoveNASResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *RemoveNASResponse) XXX_Merge(src proto.Message)
- func (m *RemoveNASResponse) XXX_Size() int
- func (m *RemoveNASResponse) XXX_Unmarshal(b []byte) error
- type RemoveTokenRequest
- func (*RemoveTokenRequest) Descriptor() ([]byte, []int)
- func (m *RemoveTokenRequest) GetApiToken() string
- func (m *RemoveTokenRequest) GetUserId() string
- func (*RemoveTokenRequest) ProtoMessage()
- func (m *RemoveTokenRequest) Reset()
- func (m *RemoveTokenRequest) String() string
- func (m *RemoveTokenRequest) XXX_DiscardUnknown()
- func (m *RemoveTokenRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *RemoveTokenRequest) XXX_Merge(src proto.Message)
- func (m *RemoveTokenRequest) XXX_Size() int
- func (m *RemoveTokenRequest) XXX_Unmarshal(b []byte) error
- type RemoveTokenResponse
- func (*RemoveTokenResponse) Descriptor() ([]byte, []int)
- func (m *RemoveTokenResponse) GetResult() *Result
- func (*RemoveTokenResponse) ProtoMessage()
- func (m *RemoveTokenResponse) Reset()
- func (m *RemoveTokenResponse) String() string
- func (m *RemoveTokenResponse) XXX_DiscardUnknown()
- func (m *RemoveTokenResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *RemoveTokenResponse) XXX_Merge(src proto.Message)
- func (m *RemoveTokenResponse) XXX_Size() int
- func (m *RemoveTokenResponse) XXX_Unmarshal(b []byte) error
- type Result
- func (*Result) Descriptor() ([]byte, []int)
- func (m *Result) GetError() string
- func (m *Result) GetSuccess() bool
- func (*Result) ProtoMessage()
- func (m *Result) Reset()
- func (m *Result) String() string
- func (m *Result) XXX_DiscardUnknown()
- func (m *Result) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *Result) XXX_Merge(src proto.Message)
- func (m *Result) XXX_Size() int
- func (m *Result) XXX_Unmarshal(b []byte) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterHordeManagementServiceServer ¶
func RegisterHordeManagementServiceServer(s *grpc.Server, srv HordeManagementServiceServer)
Types ¶
type APN ¶
type APN struct {
ApnID int32 `protobuf:"varint,1,opt,name=ApnID,proto3" json:"ApnID,omitempty"`
Name string `protobuf:"bytes,2,opt,name=Name,proto3" json:"Name,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*APN) Descriptor ¶
func (*APN) ProtoMessage ¶
func (*APN) ProtoMessage()
func (*APN) XXX_DiscardUnknown ¶
func (m *APN) XXX_DiscardUnknown()
func (*APN) XXX_Unmarshal ¶
type APNAllocation ¶
type APNAllocation struct {
NasID int32 `protobuf:"varint,1,opt,name=NasID,proto3" json:"NasID,omitempty"`
IMSI int64 `protobuf:"varint,2,opt,name=IMSI,proto3" json:"IMSI,omitempty"`
IMEI int64 `protobuf:"varint,3,opt,name=IMEI,proto3" json:"IMEI,omitempty"`
IP string `protobuf:"bytes,4,opt,name=IP,proto3" json:"IP,omitempty"`
Created int64 `protobuf:"varint,5,opt,name=Created,proto3" json:"Created,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*APNAllocation) Descriptor ¶
func (*APNAllocation) Descriptor() ([]byte, []int)
func (*APNAllocation) GetCreated ¶
func (m *APNAllocation) GetCreated() int64
func (*APNAllocation) GetIMEI ¶
func (m *APNAllocation) GetIMEI() int64
func (*APNAllocation) GetIMSI ¶
func (m *APNAllocation) GetIMSI() int64
func (*APNAllocation) GetIP ¶
func (m *APNAllocation) GetIP() string
func (*APNAllocation) GetNasID ¶
func (m *APNAllocation) GetNasID() int32
func (*APNAllocation) ProtoMessage ¶
func (*APNAllocation) ProtoMessage()
func (*APNAllocation) Reset ¶
func (m *APNAllocation) Reset()
func (*APNAllocation) String ¶
func (m *APNAllocation) String() string
func (*APNAllocation) XXX_DiscardUnknown ¶
func (m *APNAllocation) XXX_DiscardUnknown()
func (*APNAllocation) XXX_Marshal ¶
func (m *APNAllocation) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*APNAllocation) XXX_Merge ¶
func (m *APNAllocation) XXX_Merge(src proto.Message)
func (*APNAllocation) XXX_Size ¶
func (m *APNAllocation) XXX_Size() int
func (*APNAllocation) XXX_Unmarshal ¶
func (m *APNAllocation) XXX_Unmarshal(b []byte) error
type APNConfig ¶
type APNConfig struct {
APN *APN `protobuf:"bytes,1,opt,name=APN,proto3" json:"APN,omitempty"`
NasRanges []*NASRange `protobuf:"bytes,3,rep,name=NasRanges,proto3" json:"NasRanges,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
APNConfig is configuration for an entire APN.
func (*APNConfig) Descriptor ¶
func (*APNConfig) GetNasRanges ¶
func (*APNConfig) ProtoMessage ¶
func (*APNConfig) ProtoMessage()
func (*APNConfig) XXX_DiscardUnknown ¶
func (m *APNConfig) XXX_DiscardUnknown()
func (*APNConfig) XXX_Marshal ¶
func (*APNConfig) XXX_Unmarshal ¶
type AddAPNRequest ¶
type AddAPNRequest struct {
NewAPN *APN `protobuf:"bytes,1,opt,name=NewAPN,proto3" json:"NewAPN,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
AddAPNRequest is the request object when creating a new APN.
func (*AddAPNRequest) Descriptor ¶
func (*AddAPNRequest) Descriptor() ([]byte, []int)
func (*AddAPNRequest) GetNewAPN ¶
func (m *AddAPNRequest) GetNewAPN() *APN
func (*AddAPNRequest) ProtoMessage ¶
func (*AddAPNRequest) ProtoMessage()
func (*AddAPNRequest) Reset ¶
func (m *AddAPNRequest) Reset()
func (*AddAPNRequest) String ¶
func (m *AddAPNRequest) String() string
func (*AddAPNRequest) XXX_DiscardUnknown ¶
func (m *AddAPNRequest) XXX_DiscardUnknown()
func (*AddAPNRequest) XXX_Marshal ¶
func (m *AddAPNRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*AddAPNRequest) XXX_Merge ¶
func (m *AddAPNRequest) XXX_Merge(src proto.Message)
func (*AddAPNRequest) XXX_Size ¶
func (m *AddAPNRequest) XXX_Size() int
func (*AddAPNRequest) XXX_Unmarshal ¶
func (m *AddAPNRequest) XXX_Unmarshal(b []byte) error
type AddAPNResponse ¶
type AddAPNResponse struct {
Result *Result `protobuf:"bytes,1,opt,name=Result,proto3" json:"Result,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
AddAPNResponse is the response sent when a new APN is created.
func (*AddAPNResponse) Descriptor ¶
func (*AddAPNResponse) Descriptor() ([]byte, []int)
func (*AddAPNResponse) GetResult ¶
func (m *AddAPNResponse) GetResult() *Result
func (*AddAPNResponse) ProtoMessage ¶
func (*AddAPNResponse) ProtoMessage()
func (*AddAPNResponse) Reset ¶
func (m *AddAPNResponse) Reset()
func (*AddAPNResponse) String ¶
func (m *AddAPNResponse) String() string
func (*AddAPNResponse) XXX_DiscardUnknown ¶
func (m *AddAPNResponse) XXX_DiscardUnknown()
func (*AddAPNResponse) XXX_Marshal ¶
func (m *AddAPNResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*AddAPNResponse) XXX_Merge ¶
func (m *AddAPNResponse) XXX_Merge(src proto.Message)
func (*AddAPNResponse) XXX_Size ¶
func (m *AddAPNResponse) XXX_Size() int
func (*AddAPNResponse) XXX_Unmarshal ¶
func (m *AddAPNResponse) XXX_Unmarshal(b []byte) error
type AddAllocationRequest ¶
type AddAllocationRequest struct {
ApnID int32 `protobuf:"varint,1,opt,name=ApnID,proto3" json:"ApnID,omitempty"`
NasID int32 `protobuf:"varint,2,opt,name=NasID,proto3" json:"NasID,omitempty"`
IMSI int64 `protobuf:"varint,3,opt,name=IMSI,proto3" json:"IMSI,omitempty"`
IP string `protobuf:"bytes,4,opt,name=IP,proto3" json:"IP,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*AddAllocationRequest) Descriptor ¶
func (*AddAllocationRequest) Descriptor() ([]byte, []int)
func (*AddAllocationRequest) GetApnID ¶
func (m *AddAllocationRequest) GetApnID() int32
func (*AddAllocationRequest) GetIMSI ¶
func (m *AddAllocationRequest) GetIMSI() int64
func (*AddAllocationRequest) GetIP ¶
func (m *AddAllocationRequest) GetIP() string
func (*AddAllocationRequest) GetNasID ¶
func (m *AddAllocationRequest) GetNasID() int32
func (*AddAllocationRequest) ProtoMessage ¶
func (*AddAllocationRequest) ProtoMessage()
func (*AddAllocationRequest) Reset ¶
func (m *AddAllocationRequest) Reset()
func (*AddAllocationRequest) String ¶
func (m *AddAllocationRequest) String() string
func (*AddAllocationRequest) XXX_DiscardUnknown ¶
func (m *AddAllocationRequest) XXX_DiscardUnknown()
func (*AddAllocationRequest) XXX_Marshal ¶
func (m *AddAllocationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*AddAllocationRequest) XXX_Merge ¶
func (m *AddAllocationRequest) XXX_Merge(src proto.Message)
func (*AddAllocationRequest) XXX_Size ¶
func (m *AddAllocationRequest) XXX_Size() int
func (*AddAllocationRequest) XXX_Unmarshal ¶
func (m *AddAllocationRequest) XXX_Unmarshal(b []byte) error
type AddAllocationResponse ¶
type AddAllocationResponse struct {
Result *Result `protobuf:"bytes,1,opt,name=Result,proto3" json:"Result,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*AddAllocationResponse) Descriptor ¶
func (*AddAllocationResponse) Descriptor() ([]byte, []int)
func (*AddAllocationResponse) GetResult ¶
func (m *AddAllocationResponse) GetResult() *Result
func (*AddAllocationResponse) ProtoMessage ¶
func (*AddAllocationResponse) ProtoMessage()
func (*AddAllocationResponse) Reset ¶
func (m *AddAllocationResponse) Reset()
func (*AddAllocationResponse) String ¶
func (m *AddAllocationResponse) String() string
func (*AddAllocationResponse) XXX_DiscardUnknown ¶
func (m *AddAllocationResponse) XXX_DiscardUnknown()
func (*AddAllocationResponse) XXX_Marshal ¶
func (m *AddAllocationResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*AddAllocationResponse) XXX_Merge ¶
func (m *AddAllocationResponse) XXX_Merge(src proto.Message)
func (*AddAllocationResponse) XXX_Size ¶
func (m *AddAllocationResponse) XXX_Size() int
func (*AddAllocationResponse) XXX_Unmarshal ¶
func (m *AddAllocationResponse) XXX_Unmarshal(b []byte) error
type AddNASRequest ¶
type AddNASRequest struct {
ApnID int32 `protobuf:"varint,1,opt,name=ApnID,proto3" json:"ApnID,omitempty"`
NewRange *NASRange `protobuf:"bytes,2,opt,name=NewRange,proto3" json:"NewRange,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*AddNASRequest) Descriptor ¶
func (*AddNASRequest) Descriptor() ([]byte, []int)
func (*AddNASRequest) GetApnID ¶
func (m *AddNASRequest) GetApnID() int32
func (*AddNASRequest) GetNewRange ¶
func (m *AddNASRequest) GetNewRange() *NASRange
func (*AddNASRequest) ProtoMessage ¶
func (*AddNASRequest) ProtoMessage()
func (*AddNASRequest) Reset ¶
func (m *AddNASRequest) Reset()
func (*AddNASRequest) String ¶
func (m *AddNASRequest) String() string
func (*AddNASRequest) XXX_DiscardUnknown ¶
func (m *AddNASRequest) XXX_DiscardUnknown()
func (*AddNASRequest) XXX_Marshal ¶
func (m *AddNASRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*AddNASRequest) XXX_Merge ¶
func (m *AddNASRequest) XXX_Merge(src proto.Message)
func (*AddNASRequest) XXX_Size ¶
func (m *AddNASRequest) XXX_Size() int
func (*AddNASRequest) XXX_Unmarshal ¶
func (m *AddNASRequest) XXX_Unmarshal(b []byte) error
type AddNASResponse ¶
type AddNASResponse struct {
Result *Result `protobuf:"bytes,1,opt,name=Result,proto3" json:"Result,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*AddNASResponse) Descriptor ¶
func (*AddNASResponse) Descriptor() ([]byte, []int)
func (*AddNASResponse) GetResult ¶
func (m *AddNASResponse) GetResult() *Result
func (*AddNASResponse) ProtoMessage ¶
func (*AddNASResponse) ProtoMessage()
func (*AddNASResponse) Reset ¶
func (m *AddNASResponse) Reset()
func (*AddNASResponse) String ¶
func (m *AddNASResponse) String() string
func (*AddNASResponse) XXX_DiscardUnknown ¶
func (m *AddNASResponse) XXX_DiscardUnknown()
func (*AddNASResponse) XXX_Marshal ¶
func (m *AddNASResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*AddNASResponse) XXX_Merge ¶
func (m *AddNASResponse) XXX_Merge(src proto.Message)
func (*AddNASResponse) XXX_Size ¶
func (m *AddNASResponse) XXX_Size() int
func (*AddNASResponse) XXX_Unmarshal ¶
func (m *AddNASResponse) XXX_Unmarshal(b []byte) error
type AddTokenRequest ¶
type AddTokenRequest struct {
UserId string `protobuf:"bytes,1,opt,name=UserId,proto3" json:"UserId,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*AddTokenRequest) Descriptor ¶
func (*AddTokenRequest) Descriptor() ([]byte, []int)
func (*AddTokenRequest) GetUserId ¶
func (m *AddTokenRequest) GetUserId() string
func (*AddTokenRequest) ProtoMessage ¶
func (*AddTokenRequest) ProtoMessage()
func (*AddTokenRequest) Reset ¶
func (m *AddTokenRequest) Reset()
func (*AddTokenRequest) String ¶
func (m *AddTokenRequest) String() string
func (*AddTokenRequest) XXX_DiscardUnknown ¶
func (m *AddTokenRequest) XXX_DiscardUnknown()
func (*AddTokenRequest) XXX_Marshal ¶
func (m *AddTokenRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*AddTokenRequest) XXX_Merge ¶
func (m *AddTokenRequest) XXX_Merge(src proto.Message)
func (*AddTokenRequest) XXX_Size ¶
func (m *AddTokenRequest) XXX_Size() int
func (*AddTokenRequest) XXX_Unmarshal ¶
func (m *AddTokenRequest) XXX_Unmarshal(b []byte) error
type AddTokenResponse ¶
type AddTokenResponse struct {
Result *Result `protobuf:"bytes,1,opt,name=Result,proto3" json:"Result,omitempty"`
ApiToken string `protobuf:"bytes,2,opt,name=ApiToken,proto3" json:"ApiToken,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*AddTokenResponse) Descriptor ¶
func (*AddTokenResponse) Descriptor() ([]byte, []int)
func (*AddTokenResponse) GetApiToken ¶
func (m *AddTokenResponse) GetApiToken() string
func (*AddTokenResponse) GetResult ¶
func (m *AddTokenResponse) GetResult() *Result
func (*AddTokenResponse) ProtoMessage ¶
func (*AddTokenResponse) ProtoMessage()
func (*AddTokenResponse) Reset ¶
func (m *AddTokenResponse) Reset()
func (*AddTokenResponse) String ¶
func (m *AddTokenResponse) String() string
func (*AddTokenResponse) XXX_DiscardUnknown ¶
func (m *AddTokenResponse) XXX_DiscardUnknown()
func (*AddTokenResponse) XXX_Marshal ¶
func (m *AddTokenResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*AddTokenResponse) XXX_Merge ¶
func (m *AddTokenResponse) XXX_Merge(src proto.Message)
func (*AddTokenResponse) XXX_Size ¶
func (m *AddTokenResponse) XXX_Size() int
func (*AddTokenResponse) XXX_Unmarshal ¶
func (m *AddTokenResponse) XXX_Unmarshal(b []byte) error
type AddUserRequest ¶
type AddUserRequest struct {
Name string `protobuf:"bytes,1,opt,name=Name,proto3" json:"Name,omitempty"`
Email string `protobuf:"bytes,2,opt,name=Email,proto3" json:"Email,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*AddUserRequest) Descriptor ¶
func (*AddUserRequest) Descriptor() ([]byte, []int)
func (*AddUserRequest) GetEmail ¶
func (m *AddUserRequest) GetEmail() string
func (*AddUserRequest) GetName ¶
func (m *AddUserRequest) GetName() string
func (*AddUserRequest) ProtoMessage ¶
func (*AddUserRequest) ProtoMessage()
func (*AddUserRequest) Reset ¶
func (m *AddUserRequest) Reset()
func (*AddUserRequest) String ¶
func (m *AddUserRequest) String() string
func (*AddUserRequest) XXX_DiscardUnknown ¶
func (m *AddUserRequest) XXX_DiscardUnknown()
func (*AddUserRequest) XXX_Marshal ¶
func (m *AddUserRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*AddUserRequest) XXX_Merge ¶
func (m *AddUserRequest) XXX_Merge(src proto.Message)
func (*AddUserRequest) XXX_Size ¶
func (m *AddUserRequest) XXX_Size() int
func (*AddUserRequest) XXX_Unmarshal ¶
func (m *AddUserRequest) XXX_Unmarshal(b []byte) error
type AddUserResponse ¶
type AddUserResponse struct {
Result *Result `protobuf:"bytes,1,opt,name=Result,proto3" json:"Result,omitempty"`
UserId string `protobuf:"bytes,2,opt,name=UserId,proto3" json:"UserId,omitempty"`
ApiToken string `protobuf:"bytes,3,opt,name=ApiToken,proto3" json:"ApiToken,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*AddUserResponse) Descriptor ¶
func (*AddUserResponse) Descriptor() ([]byte, []int)
func (*AddUserResponse) GetApiToken ¶
func (m *AddUserResponse) GetApiToken() string
func (*AddUserResponse) GetResult ¶
func (m *AddUserResponse) GetResult() *Result
func (*AddUserResponse) GetUserId ¶
func (m *AddUserResponse) GetUserId() string
func (*AddUserResponse) ProtoMessage ¶
func (*AddUserResponse) ProtoMessage()
func (*AddUserResponse) Reset ¶
func (m *AddUserResponse) Reset()
func (*AddUserResponse) String ¶
func (m *AddUserResponse) String() string
func (*AddUserResponse) XXX_DiscardUnknown ¶
func (m *AddUserResponse) XXX_DiscardUnknown()
func (*AddUserResponse) XXX_Marshal ¶
func (m *AddUserResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*AddUserResponse) XXX_Merge ¶
func (m *AddUserResponse) XXX_Merge(src proto.Message)
func (*AddUserResponse) XXX_Size ¶
func (m *AddUserResponse) XXX_Size() int
func (*AddUserResponse) XXX_Unmarshal ¶
func (m *AddUserResponse) XXX_Unmarshal(b []byte) error
type HordeManagementServiceClient ¶
type HordeManagementServiceClient interface {
// AddAPN creates a new APN. One or more NASRange elements must be supplied.
AddAPN(ctx context.Context, in *AddAPNRequest, opts ...grpc.CallOption) (*AddAPNResponse, error)
// AddAllocation allocates a new IP address for an APN. This is for
// debugging and diagnostics; usually this is done through the RADISU service.
AddAllocation(ctx context.Context, in *AddAllocationRequest, opts ...grpc.CallOption) (*AddAllocationResponse, error)
// RemoveAPN removes an APN. The APN must not contain any allocations or
// NAS CIDRs when it is deleted. ListAPNAllocations and RemoveAPNAllocation
// must be used to remove allocations. This might seem cumbersome but it
// might prevent the operators doing something *really* stupid.
RemoveAPN(ctx context.Context, in *RemoveAPNRequest, opts ...grpc.CallOption) (*RemoveAPNResponse, error)
// ReloadAPN reloads the APN and NAS list in memory
ReloadAPN(ctx context.Context, in *ReloadAPNRequest, opts ...grpc.CallOption) (*ReloadAPNResponse, error)
// AddNAS adds a NAS CIDR to the APN
AddNAS(ctx context.Context, in *AddNASRequest, opts ...grpc.CallOption) (*AddNASResponse, error)
// RemoveNAS removes a NAS CIDR from an APN. The NAS CIDR cannot contain any
// allocations.
RemoveNAS(ctx context.Context, in *RemoveNASRequest, opts ...grpc.CallOption) (*RemoveNASResponse, error)
// ListAPNAllocations lists all allocations for a particular APN. The first
// 1000 allocations for that APN is included.
ListAPNAllocations(ctx context.Context, in *ListAPNAllocationsRequest, opts ...grpc.CallOption) (*ListAPNAllocationsResponse, error)
// RemoveAPNAllocation removes a single allocation from the APN. The total
// number of allocations might be in the millions. This might seem
// cumbersome but it's clunky for a reason. If you try to remove an APN
// with millions of devices and the APN is still in use you'll be fighting
// an uphill battle which is *exactly* what you want in that case :)
RemoveAPNAllocation(ctx context.Context, in *RemoveAPNAllocationRequest, opts ...grpc.CallOption) (*RemoveAPNAllocationResponse, error)
// ListAPN lists the configured APNs
ListAPN(ctx context.Context, in *ListAPNRequest, opts ...grpc.CallOption) (*ListAPNResponse, error)
// AddUser creates a new user in the backend store. This is mostly for
// M2M users where there's no human on the other side, typically major
// integrations with Horde. This user can not log in via the regular
// authentication methods.
AddUser(ctx context.Context, in *AddUserRequest, opts ...grpc.CallOption) (*AddUserResponse, error)
// AddToken adds a new API token to a user created with AddUser. This method
// will not work with users created through the usual authentication methods.
AddToken(ctx context.Context, in *AddTokenRequest, opts ...grpc.CallOption) (*AddTokenResponse, error)
// RemoveToken removes a token from an internal user created with AddUser.
// Used in combination with AddToken this can be used to rotate API tokens
// for M2M users.
RemoveToken(ctx context.Context, in *RemoveTokenRequest, opts ...grpc.CallOption) (*RemoveTokenResponse, error)
}
HordeManagementServiceClient is the client API for HordeManagementService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewHordeManagementServiceClient ¶
func NewHordeManagementServiceClient(cc *grpc.ClientConn) HordeManagementServiceClient
type HordeManagementServiceServer ¶
type HordeManagementServiceServer interface {
// AddAPN creates a new APN. One or more NASRange elements must be supplied.
AddAPN(context.Context, *AddAPNRequest) (*AddAPNResponse, error)
// AddAllocation allocates a new IP address for an APN. This is for
// debugging and diagnostics; usually this is done through the RADISU service.
AddAllocation(context.Context, *AddAllocationRequest) (*AddAllocationResponse, error)
// RemoveAPN removes an APN. The APN must not contain any allocations or
// NAS CIDRs when it is deleted. ListAPNAllocations and RemoveAPNAllocation
// must be used to remove allocations. This might seem cumbersome but it
// might prevent the operators doing something *really* stupid.
RemoveAPN(context.Context, *RemoveAPNRequest) (*RemoveAPNResponse, error)
// ReloadAPN reloads the APN and NAS list in memory
ReloadAPN(context.Context, *ReloadAPNRequest) (*ReloadAPNResponse, error)
// AddNAS adds a NAS CIDR to the APN
AddNAS(context.Context, *AddNASRequest) (*AddNASResponse, error)
// RemoveNAS removes a NAS CIDR from an APN. The NAS CIDR cannot contain any
// allocations.
RemoveNAS(context.Context, *RemoveNASRequest) (*RemoveNASResponse, error)
// ListAPNAllocations lists all allocations for a particular APN. The first
// 1000 allocations for that APN is included.
ListAPNAllocations(context.Context, *ListAPNAllocationsRequest) (*ListAPNAllocationsResponse, error)
// RemoveAPNAllocation removes a single allocation from the APN. The total
// number of allocations might be in the millions. This might seem
// cumbersome but it's clunky for a reason. If you try to remove an APN
// with millions of devices and the APN is still in use you'll be fighting
// an uphill battle which is *exactly* what you want in that case :)
RemoveAPNAllocation(context.Context, *RemoveAPNAllocationRequest) (*RemoveAPNAllocationResponse, error)
// ListAPN lists the configured APNs
ListAPN(context.Context, *ListAPNRequest) (*ListAPNResponse, error)
// AddUser creates a new user in the backend store. This is mostly for
// M2M users where there's no human on the other side, typically major
// integrations with Horde. This user can not log in via the regular
// authentication methods.
AddUser(context.Context, *AddUserRequest) (*AddUserResponse, error)
// AddToken adds a new API token to a user created with AddUser. This method
// will not work with users created through the usual authentication methods.
AddToken(context.Context, *AddTokenRequest) (*AddTokenResponse, error)
// RemoveToken removes a token from an internal user created with AddUser.
// Used in combination with AddToken this can be used to rotate API tokens
// for M2M users.
RemoveToken(context.Context, *RemoveTokenRequest) (*RemoveTokenResponse, error)
}
HordeManagementServiceServer is the server API for HordeManagementService service.
type ListAPNAllocationsRequest ¶
type ListAPNAllocationsRequest struct {
ApnID int32 `protobuf:"varint,1,opt,name=ApnID,proto3" json:"ApnID,omitempty"`
NasID int32 `protobuf:"varint,2,opt,name=NasID,proto3" json:"NasID,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*ListAPNAllocationsRequest) Descriptor ¶
func (*ListAPNAllocationsRequest) Descriptor() ([]byte, []int)
func (*ListAPNAllocationsRequest) GetApnID ¶
func (m *ListAPNAllocationsRequest) GetApnID() int32
func (*ListAPNAllocationsRequest) GetNasID ¶
func (m *ListAPNAllocationsRequest) GetNasID() int32
func (*ListAPNAllocationsRequest) ProtoMessage ¶
func (*ListAPNAllocationsRequest) ProtoMessage()
func (*ListAPNAllocationsRequest) Reset ¶
func (m *ListAPNAllocationsRequest) Reset()
func (*ListAPNAllocationsRequest) String ¶
func (m *ListAPNAllocationsRequest) String() string
func (*ListAPNAllocationsRequest) XXX_DiscardUnknown ¶
func (m *ListAPNAllocationsRequest) XXX_DiscardUnknown()
func (*ListAPNAllocationsRequest) XXX_Marshal ¶
func (m *ListAPNAllocationsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ListAPNAllocationsRequest) XXX_Merge ¶
func (m *ListAPNAllocationsRequest) XXX_Merge(src proto.Message)
func (*ListAPNAllocationsRequest) XXX_Size ¶
func (m *ListAPNAllocationsRequest) XXX_Size() int
func (*ListAPNAllocationsRequest) XXX_Unmarshal ¶
func (m *ListAPNAllocationsRequest) XXX_Unmarshal(b []byte) error
type ListAPNAllocationsResponse ¶
type ListAPNAllocationsResponse struct {
Result *Result `protobuf:"bytes,1,opt,name=Result,proto3" json:"Result,omitempty"`
Allocations []*APNAllocation `protobuf:"bytes,2,rep,name=Allocations,proto3" json:"Allocations,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*ListAPNAllocationsResponse) Descriptor ¶
func (*ListAPNAllocationsResponse) Descriptor() ([]byte, []int)
func (*ListAPNAllocationsResponse) GetAllocations ¶
func (m *ListAPNAllocationsResponse) GetAllocations() []*APNAllocation
func (*ListAPNAllocationsResponse) GetResult ¶
func (m *ListAPNAllocationsResponse) GetResult() *Result
func (*ListAPNAllocationsResponse) ProtoMessage ¶
func (*ListAPNAllocationsResponse) ProtoMessage()
func (*ListAPNAllocationsResponse) Reset ¶
func (m *ListAPNAllocationsResponse) Reset()
func (*ListAPNAllocationsResponse) String ¶
func (m *ListAPNAllocationsResponse) String() string
func (*ListAPNAllocationsResponse) XXX_DiscardUnknown ¶
func (m *ListAPNAllocationsResponse) XXX_DiscardUnknown()
func (*ListAPNAllocationsResponse) XXX_Marshal ¶
func (m *ListAPNAllocationsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ListAPNAllocationsResponse) XXX_Merge ¶
func (m *ListAPNAllocationsResponse) XXX_Merge(src proto.Message)
func (*ListAPNAllocationsResponse) XXX_Size ¶
func (m *ListAPNAllocationsResponse) XXX_Size() int
func (*ListAPNAllocationsResponse) XXX_Unmarshal ¶
func (m *ListAPNAllocationsResponse) XXX_Unmarshal(b []byte) error
type ListAPNRequest ¶
type ListAPNRequest struct {
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
ListAPNRequest is the request object for the ListAPN method.
func (*ListAPNRequest) Descriptor ¶
func (*ListAPNRequest) Descriptor() ([]byte, []int)
func (*ListAPNRequest) ProtoMessage ¶
func (*ListAPNRequest) ProtoMessage()
func (*ListAPNRequest) Reset ¶
func (m *ListAPNRequest) Reset()
func (*ListAPNRequest) String ¶
func (m *ListAPNRequest) String() string
func (*ListAPNRequest) XXX_DiscardUnknown ¶
func (m *ListAPNRequest) XXX_DiscardUnknown()
func (*ListAPNRequest) XXX_Marshal ¶
func (m *ListAPNRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ListAPNRequest) XXX_Merge ¶
func (m *ListAPNRequest) XXX_Merge(src proto.Message)
func (*ListAPNRequest) XXX_Size ¶
func (m *ListAPNRequest) XXX_Size() int
func (*ListAPNRequest) XXX_Unmarshal ¶
func (m *ListAPNRequest) XXX_Unmarshal(b []byte) error
type ListAPNResponse ¶
type ListAPNResponse struct {
Result *Result `protobuf:"bytes,1,opt,name=Result,proto3" json:"Result,omitempty"`
APNs []*APNConfig `protobuf:"bytes,2,rep,name=APNs,proto3" json:"APNs,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
ListAPNResponse is the response object for the ListAPN method.
func (*ListAPNResponse) Descriptor ¶
func (*ListAPNResponse) Descriptor() ([]byte, []int)
func (*ListAPNResponse) GetAPNs ¶
func (m *ListAPNResponse) GetAPNs() []*APNConfig
func (*ListAPNResponse) GetResult ¶
func (m *ListAPNResponse) GetResult() *Result
func (*ListAPNResponse) ProtoMessage ¶
func (*ListAPNResponse) ProtoMessage()
func (*ListAPNResponse) Reset ¶
func (m *ListAPNResponse) Reset()
func (*ListAPNResponse) String ¶
func (m *ListAPNResponse) String() string
func (*ListAPNResponse) XXX_DiscardUnknown ¶
func (m *ListAPNResponse) XXX_DiscardUnknown()
func (*ListAPNResponse) XXX_Marshal ¶
func (m *ListAPNResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ListAPNResponse) XXX_Merge ¶
func (m *ListAPNResponse) XXX_Merge(src proto.Message)
func (*ListAPNResponse) XXX_Size ¶
func (m *ListAPNResponse) XXX_Size() int
func (*ListAPNResponse) XXX_Unmarshal ¶
func (m *ListAPNResponse) XXX_Unmarshal(b []byte) error
type NASRange ¶
type NASRange struct {
NasID int32 `protobuf:"varint,1,opt,name=NasID,proto3" json:"NasID,omitempty"`
NasIdentifier string `protobuf:"bytes,2,opt,name=NasIdentifier,proto3" json:"NasIdentifier,omitempty"`
CIDR string `protobuf:"bytes,3,opt,name=CIDR,proto3" json:"CIDR,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
NASRange represents a single Network Authentication Server that emits RADIUS requests. Each server expects a particular range.
func (*NASRange) Descriptor ¶
func (*NASRange) GetNasIdentifier ¶
func (*NASRange) ProtoMessage ¶
func (*NASRange) ProtoMessage()
func (*NASRange) XXX_DiscardUnknown ¶
func (m *NASRange) XXX_DiscardUnknown()
func (*NASRange) XXX_Marshal ¶
func (*NASRange) XXX_Unmarshal ¶
type ReloadAPNRequest ¶
type ReloadAPNRequest struct {
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
ReloadAPNRequest is the request object for the ReloadAPN method
func (*ReloadAPNRequest) Descriptor ¶
func (*ReloadAPNRequest) Descriptor() ([]byte, []int)
func (*ReloadAPNRequest) ProtoMessage ¶
func (*ReloadAPNRequest) ProtoMessage()
func (*ReloadAPNRequest) Reset ¶
func (m *ReloadAPNRequest) Reset()
func (*ReloadAPNRequest) String ¶
func (m *ReloadAPNRequest) String() string
func (*ReloadAPNRequest) XXX_DiscardUnknown ¶
func (m *ReloadAPNRequest) XXX_DiscardUnknown()
func (*ReloadAPNRequest) XXX_Marshal ¶
func (m *ReloadAPNRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ReloadAPNRequest) XXX_Merge ¶
func (m *ReloadAPNRequest) XXX_Merge(src proto.Message)
func (*ReloadAPNRequest) XXX_Size ¶
func (m *ReloadAPNRequest) XXX_Size() int
func (*ReloadAPNRequest) XXX_Unmarshal ¶
func (m *ReloadAPNRequest) XXX_Unmarshal(b []byte) error
type ReloadAPNResponse ¶
type ReloadAPNResponse struct {
Result *Result `protobuf:"bytes,1,opt,name=Result,proto3" json:"Result,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
ReloadAPNResponse is the response object for the ReloadAPN method
func (*ReloadAPNResponse) Descriptor ¶
func (*ReloadAPNResponse) Descriptor() ([]byte, []int)
func (*ReloadAPNResponse) GetResult ¶
func (m *ReloadAPNResponse) GetResult() *Result
func (*ReloadAPNResponse) ProtoMessage ¶
func (*ReloadAPNResponse) ProtoMessage()
func (*ReloadAPNResponse) Reset ¶
func (m *ReloadAPNResponse) Reset()
func (*ReloadAPNResponse) String ¶
func (m *ReloadAPNResponse) String() string
func (*ReloadAPNResponse) XXX_DiscardUnknown ¶
func (m *ReloadAPNResponse) XXX_DiscardUnknown()
func (*ReloadAPNResponse) XXX_Marshal ¶
func (m *ReloadAPNResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ReloadAPNResponse) XXX_Merge ¶
func (m *ReloadAPNResponse) XXX_Merge(src proto.Message)
func (*ReloadAPNResponse) XXX_Size ¶
func (m *ReloadAPNResponse) XXX_Size() int
func (*ReloadAPNResponse) XXX_Unmarshal ¶
func (m *ReloadAPNResponse) XXX_Unmarshal(b []byte) error
type RemoveAPNAllocationRequest ¶
type RemoveAPNAllocationRequest struct {
// APN ID is required and must be set.
ApnID int32 `protobuf:"varint,1,opt,name=ApnID,proto3" json:"ApnID,omitempty"`
// NasID is required and must be set.
NasID int32 `protobuf:"varint,2,opt,name=NasID,proto3" json:"NasID,omitempty"`
// IMSI field is required and must be set.
IMSI int64 `protobuf:"varint,3,opt,name=IMSI,proto3" json:"IMSI,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*RemoveAPNAllocationRequest) Descriptor ¶
func (*RemoveAPNAllocationRequest) Descriptor() ([]byte, []int)
func (*RemoveAPNAllocationRequest) GetApnID ¶
func (m *RemoveAPNAllocationRequest) GetApnID() int32
func (*RemoveAPNAllocationRequest) GetIMSI ¶
func (m *RemoveAPNAllocationRequest) GetIMSI() int64
func (*RemoveAPNAllocationRequest) GetNasID ¶
func (m *RemoveAPNAllocationRequest) GetNasID() int32
func (*RemoveAPNAllocationRequest) ProtoMessage ¶
func (*RemoveAPNAllocationRequest) ProtoMessage()
func (*RemoveAPNAllocationRequest) Reset ¶
func (m *RemoveAPNAllocationRequest) Reset()
func (*RemoveAPNAllocationRequest) String ¶
func (m *RemoveAPNAllocationRequest) String() string
func (*RemoveAPNAllocationRequest) XXX_DiscardUnknown ¶
func (m *RemoveAPNAllocationRequest) XXX_DiscardUnknown()
func (*RemoveAPNAllocationRequest) XXX_Marshal ¶
func (m *RemoveAPNAllocationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*RemoveAPNAllocationRequest) XXX_Merge ¶
func (m *RemoveAPNAllocationRequest) XXX_Merge(src proto.Message)
func (*RemoveAPNAllocationRequest) XXX_Size ¶
func (m *RemoveAPNAllocationRequest) XXX_Size() int
func (*RemoveAPNAllocationRequest) XXX_Unmarshal ¶
func (m *RemoveAPNAllocationRequest) XXX_Unmarshal(b []byte) error
type RemoveAPNAllocationResponse ¶
type RemoveAPNAllocationResponse struct {
Result *Result `protobuf:"bytes,1,opt,name=Result,proto3" json:"Result,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*RemoveAPNAllocationResponse) Descriptor ¶
func (*RemoveAPNAllocationResponse) Descriptor() ([]byte, []int)
func (*RemoveAPNAllocationResponse) GetResult ¶
func (m *RemoveAPNAllocationResponse) GetResult() *Result
func (*RemoveAPNAllocationResponse) ProtoMessage ¶
func (*RemoveAPNAllocationResponse) ProtoMessage()
func (*RemoveAPNAllocationResponse) Reset ¶
func (m *RemoveAPNAllocationResponse) Reset()
func (*RemoveAPNAllocationResponse) String ¶
func (m *RemoveAPNAllocationResponse) String() string
func (*RemoveAPNAllocationResponse) XXX_DiscardUnknown ¶
func (m *RemoveAPNAllocationResponse) XXX_DiscardUnknown()
func (*RemoveAPNAllocationResponse) XXX_Marshal ¶
func (m *RemoveAPNAllocationResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*RemoveAPNAllocationResponse) XXX_Merge ¶
func (m *RemoveAPNAllocationResponse) XXX_Merge(src proto.Message)
func (*RemoveAPNAllocationResponse) XXX_Size ¶
func (m *RemoveAPNAllocationResponse) XXX_Size() int
func (*RemoveAPNAllocationResponse) XXX_Unmarshal ¶
func (m *RemoveAPNAllocationResponse) XXX_Unmarshal(b []byte) error
type RemoveAPNRequest ¶
type RemoveAPNRequest struct {
ApnID int32 `protobuf:"varint,1,opt,name=ApnID,proto3" json:"ApnID,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
RemoveAPNRequest is the request object for the RemoveAPN method.
func (*RemoveAPNRequest) Descriptor ¶
func (*RemoveAPNRequest) Descriptor() ([]byte, []int)
func (*RemoveAPNRequest) GetApnID ¶
func (m *RemoveAPNRequest) GetApnID() int32
func (*RemoveAPNRequest) ProtoMessage ¶
func (*RemoveAPNRequest) ProtoMessage()
func (*RemoveAPNRequest) Reset ¶
func (m *RemoveAPNRequest) Reset()
func (*RemoveAPNRequest) String ¶
func (m *RemoveAPNRequest) String() string
func (*RemoveAPNRequest) XXX_DiscardUnknown ¶
func (m *RemoveAPNRequest) XXX_DiscardUnknown()
func (*RemoveAPNRequest) XXX_Marshal ¶
func (m *RemoveAPNRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*RemoveAPNRequest) XXX_Merge ¶
func (m *RemoveAPNRequest) XXX_Merge(src proto.Message)
func (*RemoveAPNRequest) XXX_Size ¶
func (m *RemoveAPNRequest) XXX_Size() int
func (*RemoveAPNRequest) XXX_Unmarshal ¶
func (m *RemoveAPNRequest) XXX_Unmarshal(b []byte) error
type RemoveAPNResponse ¶
type RemoveAPNResponse struct {
Result *Result `protobuf:"bytes,1,opt,name=Result,proto3" json:"Result,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
RemoveAPNResponse is the response object for the RemoveAPN method.
func (*RemoveAPNResponse) Descriptor ¶
func (*RemoveAPNResponse) Descriptor() ([]byte, []int)
func (*RemoveAPNResponse) GetResult ¶
func (m *RemoveAPNResponse) GetResult() *Result
func (*RemoveAPNResponse) ProtoMessage ¶
func (*RemoveAPNResponse) ProtoMessage()
func (*RemoveAPNResponse) Reset ¶
func (m *RemoveAPNResponse) Reset()
func (*RemoveAPNResponse) String ¶
func (m *RemoveAPNResponse) String() string
func (*RemoveAPNResponse) XXX_DiscardUnknown ¶
func (m *RemoveAPNResponse) XXX_DiscardUnknown()
func (*RemoveAPNResponse) XXX_Marshal ¶
func (m *RemoveAPNResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*RemoveAPNResponse) XXX_Merge ¶
func (m *RemoveAPNResponse) XXX_Merge(src proto.Message)
func (*RemoveAPNResponse) XXX_Size ¶
func (m *RemoveAPNResponse) XXX_Size() int
func (*RemoveAPNResponse) XXX_Unmarshal ¶
func (m *RemoveAPNResponse) XXX_Unmarshal(b []byte) error
type RemoveNASRequest ¶
type RemoveNASRequest struct {
ApnID int32 `protobuf:"varint,1,opt,name=ApnID,proto3" json:"ApnID,omitempty"`
NasID int32 `protobuf:"varint,2,opt,name=NasID,proto3" json:"NasID,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*RemoveNASRequest) Descriptor ¶
func (*RemoveNASRequest) Descriptor() ([]byte, []int)
func (*RemoveNASRequest) GetApnID ¶
func (m *RemoveNASRequest) GetApnID() int32
func (*RemoveNASRequest) GetNasID ¶
func (m *RemoveNASRequest) GetNasID() int32
func (*RemoveNASRequest) ProtoMessage ¶
func (*RemoveNASRequest) ProtoMessage()
func (*RemoveNASRequest) Reset ¶
func (m *RemoveNASRequest) Reset()
func (*RemoveNASRequest) String ¶
func (m *RemoveNASRequest) String() string
func (*RemoveNASRequest) XXX_DiscardUnknown ¶
func (m *RemoveNASRequest) XXX_DiscardUnknown()
func (*RemoveNASRequest) XXX_Marshal ¶
func (m *RemoveNASRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*RemoveNASRequest) XXX_Merge ¶
func (m *RemoveNASRequest) XXX_Merge(src proto.Message)
func (*RemoveNASRequest) XXX_Size ¶
func (m *RemoveNASRequest) XXX_Size() int
func (*RemoveNASRequest) XXX_Unmarshal ¶
func (m *RemoveNASRequest) XXX_Unmarshal(b []byte) error
type RemoveNASResponse ¶
type RemoveNASResponse struct {
Result *Result `protobuf:"bytes,1,opt,name=Result,proto3" json:"Result,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*RemoveNASResponse) Descriptor ¶
func (*RemoveNASResponse) Descriptor() ([]byte, []int)
func (*RemoveNASResponse) GetResult ¶
func (m *RemoveNASResponse) GetResult() *Result
func (*RemoveNASResponse) ProtoMessage ¶
func (*RemoveNASResponse) ProtoMessage()
func (*RemoveNASResponse) Reset ¶
func (m *RemoveNASResponse) Reset()
func (*RemoveNASResponse) String ¶
func (m *RemoveNASResponse) String() string
func (*RemoveNASResponse) XXX_DiscardUnknown ¶
func (m *RemoveNASResponse) XXX_DiscardUnknown()
func (*RemoveNASResponse) XXX_Marshal ¶
func (m *RemoveNASResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*RemoveNASResponse) XXX_Merge ¶
func (m *RemoveNASResponse) XXX_Merge(src proto.Message)
func (*RemoveNASResponse) XXX_Size ¶
func (m *RemoveNASResponse) XXX_Size() int
func (*RemoveNASResponse) XXX_Unmarshal ¶
func (m *RemoveNASResponse) XXX_Unmarshal(b []byte) error
type RemoveTokenRequest ¶
type RemoveTokenRequest struct {
UserId string `protobuf:"bytes,1,opt,name=UserId,proto3" json:"UserId,omitempty"`
ApiToken string `protobuf:"bytes,2,opt,name=ApiToken,proto3" json:"ApiToken,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*RemoveTokenRequest) Descriptor ¶
func (*RemoveTokenRequest) Descriptor() ([]byte, []int)
func (*RemoveTokenRequest) GetApiToken ¶
func (m *RemoveTokenRequest) GetApiToken() string
func (*RemoveTokenRequest) GetUserId ¶
func (m *RemoveTokenRequest) GetUserId() string
func (*RemoveTokenRequest) ProtoMessage ¶
func (*RemoveTokenRequest) ProtoMessage()
func (*RemoveTokenRequest) Reset ¶
func (m *RemoveTokenRequest) Reset()
func (*RemoveTokenRequest) String ¶
func (m *RemoveTokenRequest) String() string
func (*RemoveTokenRequest) XXX_DiscardUnknown ¶
func (m *RemoveTokenRequest) XXX_DiscardUnknown()
func (*RemoveTokenRequest) XXX_Marshal ¶
func (m *RemoveTokenRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*RemoveTokenRequest) XXX_Merge ¶
func (m *RemoveTokenRequest) XXX_Merge(src proto.Message)
func (*RemoveTokenRequest) XXX_Size ¶
func (m *RemoveTokenRequest) XXX_Size() int
func (*RemoveTokenRequest) XXX_Unmarshal ¶
func (m *RemoveTokenRequest) XXX_Unmarshal(b []byte) error
type RemoveTokenResponse ¶
type RemoveTokenResponse struct {
Result *Result `protobuf:"bytes,1,opt,name=Result,proto3" json:"Result,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*RemoveTokenResponse) Descriptor ¶
func (*RemoveTokenResponse) Descriptor() ([]byte, []int)
func (*RemoveTokenResponse) GetResult ¶
func (m *RemoveTokenResponse) GetResult() *Result
func (*RemoveTokenResponse) ProtoMessage ¶
func (*RemoveTokenResponse) ProtoMessage()
func (*RemoveTokenResponse) Reset ¶
func (m *RemoveTokenResponse) Reset()
func (*RemoveTokenResponse) String ¶
func (m *RemoveTokenResponse) String() string
func (*RemoveTokenResponse) XXX_DiscardUnknown ¶
func (m *RemoveTokenResponse) XXX_DiscardUnknown()
func (*RemoveTokenResponse) XXX_Marshal ¶
func (m *RemoveTokenResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*RemoveTokenResponse) XXX_Merge ¶
func (m *RemoveTokenResponse) XXX_Merge(src proto.Message)
func (*RemoveTokenResponse) XXX_Size ¶
func (m *RemoveTokenResponse) XXX_Size() int
func (*RemoveTokenResponse) XXX_Unmarshal ¶
func (m *RemoveTokenResponse) XXX_Unmarshal(b []byte) error
type Result ¶
type Result struct {
Success bool `protobuf:"varint,1,opt,name=Success,proto3" json:"Success,omitempty"`
Error string `protobuf:"bytes,2,opt,name=Error,proto3" json:"Error,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Result is included in the response messages to indicate success/failure. the Result message will always be set but the actual values might be invalid.
func (*Result) Descriptor ¶
func (*Result) GetSuccess ¶
func (*Result) ProtoMessage ¶
func (*Result) ProtoMessage()
func (*Result) XXX_DiscardUnknown ¶
func (m *Result) XXX_DiscardUnknown()